@@ -10,7 +10,7 @@ logger = logging.getLogger('therapy')
 logger.setLevel(logging.DEBUG)
 
 # TODO: Fix so that we don't have to change in setup.cfg
-__version__ = "0.2.15"
+__version__ = "0.2.16"
 
 
 class DownloadException(Exception):
@@ -46,12 +46,12 @@ PROHIBITED_SOURCES = {s.value.lower()
 ACCEPTED_SOURCES = SOURCES.keys() - PROHIBITED_SOURCES
 
 # Sources that we import directly
-OTHER_IDENTIFIERS = {source for source in SourceName.__members__}
+XREF_SOURCES = {source for source in SourceName.__members__}
 
 # Sources that are found in data from imported sources
-XREFS = {source for source in NamespacePrefix.__members__} - OTHER_IDENTIFIERS
+ASSOC_WITH_SOURCES = {source for source in NamespacePrefix.__members__} - XREF_SOURCES  # noqa: E501
 
-from therapy.etl import ChEMBL, Wikidata, DrugBank, NCIt, ChemIDplus, RxNorm  # noqa: F401, E402, E501
+from therapy.etl import ChEMBL, Wikidata, DrugBank, NCIt, ChemIDplus, RxNorm, HemOnc  # noqa: F401, E402, E501
 # used to get source class name from string
 SOURCES_CLASS = \
     {s.value.lower(): eval(s.value) for s in SourceName.__members__.values()}
